# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SnowProfileDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'is_profile_to_ground': 'bool',
        'snow_temp': 'TempObsDto',
        'strat_profile': 'StratProfileDto',
        'snow_density': 'list[DensityProfileDto]'
    }

    attribute_map = {
        'comment': 'Comment',
        'is_profile_to_ground': 'IsProfileToGround',
        'snow_temp': 'SnowTemp',
        'strat_profile': 'StratProfile',
        'snow_density': 'SnowDensity'
    }

    def __init__(self, comment=None, is_profile_to_ground=None, snow_temp=None, strat_profile=None, snow_density=None):  # noqa: E501
        """SnowProfileDto - a model defined in Swagger"""  # noqa: E501
        self._comment = None
        self._is_profile_to_ground = None
        self._snow_temp = None
        self._strat_profile = None
        self._snow_density = None
        self.discriminator = None
        if comment is not None:
            self.comment = comment
        if is_profile_to_ground is not None:
            self.is_profile_to_ground = is_profile_to_ground
        if snow_temp is not None:
            self.snow_temp = snow_temp
        if strat_profile is not None:
            self.strat_profile = strat_profile
        if snow_density is not None:
            self.snow_density = snow_density

    @property
    def comment(self):
        """Gets the comment of this SnowProfileDto.  # noqa: E501


        :return: The comment of this SnowProfileDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SnowProfileDto.


        :param comment: The comment of this SnowProfileDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def is_profile_to_ground(self):
        """Gets the is_profile_to_ground of this SnowProfileDto.  # noqa: E501


        :return: The is_profile_to_ground of this SnowProfileDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_profile_to_ground

    @is_profile_to_ground.setter
    def is_profile_to_ground(self, is_profile_to_ground):
        """Sets the is_profile_to_ground of this SnowProfileDto.


        :param is_profile_to_ground: The is_profile_to_ground of this SnowProfileDto.  # noqa: E501
        :type: bool
        """

        self._is_profile_to_ground = is_profile_to_ground

    @property
    def snow_temp(self):
        """Gets the snow_temp of this SnowProfileDto.  # noqa: E501


        :return: The snow_temp of this SnowProfileDto.  # noqa: E501
        :rtype: TempObsDto
        """
        return self._snow_temp

    @snow_temp.setter
    def snow_temp(self, snow_temp):
        """Sets the snow_temp of this SnowProfileDto.


        :param snow_temp: The snow_temp of this SnowProfileDto.  # noqa: E501
        :type: TempObsDto
        """

        self._snow_temp = snow_temp

    @property
    def strat_profile(self):
        """Gets the strat_profile of this SnowProfileDto.  # noqa: E501


        :return: The strat_profile of this SnowProfileDto.  # noqa: E501
        :rtype: StratProfileDto
        """
        return self._strat_profile

    @strat_profile.setter
    def strat_profile(self, strat_profile):
        """Sets the strat_profile of this SnowProfileDto.


        :param strat_profile: The strat_profile of this SnowProfileDto.  # noqa: E501
        :type: StratProfileDto
        """

        self._strat_profile = strat_profile

    @property
    def snow_density(self):
        """Gets the snow_density of this SnowProfileDto.  # noqa: E501


        :return: The snow_density of this SnowProfileDto.  # noqa: E501
        :rtype: list[DensityProfileDto]
        """
        return self._snow_density

    @snow_density.setter
    def snow_density(self, snow_density):
        """Sets the snow_density of this SnowProfileDto.


        :param snow_density: The snow_density of this SnowProfileDto.  # noqa: E501
        :type: list[DensityProfileDto]
        """

        self._snow_density = snow_density

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SnowProfileDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnowProfileDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
