from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from varsom_regobs_client.api.account_api import AccountApi
from varsom_regobs_client.api.attachment_api import AttachmentApi
from varsom_regobs_client.api.general_obs_api import GeneralObsApi
from varsom_regobs_client.api.geo_code_api import GeoCodeApi
from varsom_regobs_client.api.helptext_api import HelptextApi
from varsom_regobs_client.api.kdv_elements_api import KdvElementsApi
from varsom_regobs_client.api.location_api import LocationApi
from varsom_regobs_client.api.registration_api import RegistrationApi
from varsom_regobs_client.api.search_api import SearchApi
from varsom_regobs_client.api.token_api import TokenApi
from varsom_regobs_client.api.trip_api import TripApi
