# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ObserverCompetenceDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'competence_tid': 'int',
        'geohazard_tid': 'int',
        'competence_name': 'str',
        'competence_description': 'str'
    }

    attribute_map = {
        'competence_tid': 'CompetenceTID',
        'geohazard_tid': 'GeohazardTID',
        'competence_name': 'CompetenceName',
        'competence_description': 'CompetenceDescription'
    }

    def __init__(self, competence_tid=None, geohazard_tid=None, competence_name=None, competence_description=None):  # noqa: E501
        """ObserverCompetenceDto - a model defined in Swagger"""  # noqa: E501
        self._competence_tid = None
        self._geohazard_tid = None
        self._competence_name = None
        self._competence_description = None
        self.discriminator = None
        if competence_tid is not None:
            self.competence_tid = competence_tid
        if geohazard_tid is not None:
            self.geohazard_tid = geohazard_tid
        if competence_name is not None:
            self.competence_name = competence_name
        if competence_description is not None:
            self.competence_description = competence_description

    @property
    def competence_tid(self):
        """Gets the competence_tid of this ObserverCompetenceDto.  # noqa: E501


        :return: The competence_tid of this ObserverCompetenceDto.  # noqa: E501
        :rtype: int
        """
        return self._competence_tid

    @competence_tid.setter
    def competence_tid(self, competence_tid):
        """Sets the competence_tid of this ObserverCompetenceDto.


        :param competence_tid: The competence_tid of this ObserverCompetenceDto.  # noqa: E501
        :type: int
        """

        self._competence_tid = competence_tid

    @property
    def geohazard_tid(self):
        """Gets the geohazard_tid of this ObserverCompetenceDto.  # noqa: E501


        :return: The geohazard_tid of this ObserverCompetenceDto.  # noqa: E501
        :rtype: int
        """
        return self._geohazard_tid

    @geohazard_tid.setter
    def geohazard_tid(self, geohazard_tid):
        """Sets the geohazard_tid of this ObserverCompetenceDto.


        :param geohazard_tid: The geohazard_tid of this ObserverCompetenceDto.  # noqa: E501
        :type: int
        """

        self._geohazard_tid = geohazard_tid

    @property
    def competence_name(self):
        """Gets the competence_name of this ObserverCompetenceDto.  # noqa: E501


        :return: The competence_name of this ObserverCompetenceDto.  # noqa: E501
        :rtype: str
        """
        return self._competence_name

    @competence_name.setter
    def competence_name(self, competence_name):
        """Sets the competence_name of this ObserverCompetenceDto.


        :param competence_name: The competence_name of this ObserverCompetenceDto.  # noqa: E501
        :type: str
        """

        self._competence_name = competence_name

    @property
    def competence_description(self):
        """Gets the competence_description of this ObserverCompetenceDto.  # noqa: E501


        :return: The competence_description of this ObserverCompetenceDto.  # noqa: E501
        :rtype: str
        """
        return self._competence_description

    @competence_description.setter
    def competence_description(self, competence_description):
        """Sets the competence_description of this ObserverCompetenceDto.


        :param competence_description: The competence_description of this ObserverCompetenceDto.  # noqa: E501
        :type: str
        """

        self._competence_description = competence_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ObserverCompetenceDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObserverCompetenceDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
