# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Summary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'registration_tid': 'int',
        'registration_name': 'str',
        'summaries': 'list[RegObsGenericValue]'
    }

    attribute_map = {
        'registration_tid': 'RegistrationTID',
        'registration_name': 'RegistrationName',
        'summaries': 'Summaries'
    }

    def __init__(self, registration_tid=None, registration_name=None, summaries=None):  # noqa: E501
        """Summary - a model defined in Swagger"""  # noqa: E501
        self._registration_tid = None
        self._registration_name = None
        self._summaries = None
        self.discriminator = None
        if registration_tid is not None:
            self.registration_tid = registration_tid
        if registration_name is not None:
            self.registration_name = registration_name
        if summaries is not None:
            self.summaries = summaries

    @property
    def registration_tid(self):
        """Gets the registration_tid of this Summary.  # noqa: E501


        :return: The registration_tid of this Summary.  # noqa: E501
        :rtype: int
        """
        return self._registration_tid

    @registration_tid.setter
    def registration_tid(self, registration_tid):
        """Sets the registration_tid of this Summary.


        :param registration_tid: The registration_tid of this Summary.  # noqa: E501
        :type: int
        """

        self._registration_tid = registration_tid

    @property
    def registration_name(self):
        """Gets the registration_name of this Summary.  # noqa: E501


        :return: The registration_name of this Summary.  # noqa: E501
        :rtype: str
        """
        return self._registration_name

    @registration_name.setter
    def registration_name(self, registration_name):
        """Sets the registration_name of this Summary.


        :param registration_name: The registration_name of this Summary.  # noqa: E501
        :type: str
        """

        self._registration_name = registration_name

    @property
    def summaries(self):
        """Gets the summaries of this Summary.  # noqa: E501


        :return: The summaries of this Summary.  # noqa: E501
        :rtype: list[RegObsGenericValue]
        """
        return self._summaries

    @summaries.setter
    def summaries(self, summaries):
        """Sets the summaries of this Summary.


        :param summaries: The summaries of this Summary.  # noqa: E501
        :type: list[RegObsGenericValue]
        """

        self._summaries = summaries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Summary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Summary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
