# coding: utf-8

# flake8: noqa

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from varsom_regobs_client.api.account_api import AccountApi
from varsom_regobs_client.api.attachment_api import AttachmentApi
from varsom_regobs_client.api.general_obs_api import GeneralObsApi
from varsom_regobs_client.api.geo_code_api import GeoCodeApi
from varsom_regobs_client.api.helptext_api import HelptextApi
from varsom_regobs_client.api.kdv_elements_api import KdvElementsApi
from varsom_regobs_client.api.location_api import LocationApi
from varsom_regobs_client.api.registration_api import RegistrationApi
from varsom_regobs_client.api.search_api import SearchApi
from varsom_regobs_client.api.token_api import TokenApi
from varsom_regobs_client.api.trip_api import TripApi
# import ApiClient
from varsom_regobs_client.api_client import ApiClient
from varsom_regobs_client.configuration import Configuration
# import models into sdk package
from varsom_regobs_client.models.areas_dto import AreasDto
from varsom_regobs_client.models.at_a_glance_view_model import AtAGlanceViewModel
from varsom_regobs_client.models.attachment_view_model import AttachmentViewModel
from varsom_regobs_client.models.avalanche_activity_obs2_dto import AvalancheActivityObs2Dto
from varsom_regobs_client.models.avalanche_activity_obs2_view_model import AvalancheActivityObs2ViewModel
from varsom_regobs_client.models.avalanche_activity_obs_dto import AvalancheActivityObsDto
from varsom_regobs_client.models.avalanche_activity_obs_view_model import AvalancheActivityObsViewModel
from varsom_regobs_client.models.avalanche_danger_obs_dto import AvalancheDangerObsDto
from varsom_regobs_client.models.avalanche_danger_obs_view_model import AvalancheDangerObsViewModel
from varsom_regobs_client.models.avalanche_eval_problem2_dto import AvalancheEvalProblem2Dto
from varsom_regobs_client.models.avalanche_eval_problem2_view_model import AvalancheEvalProblem2ViewModel
from varsom_regobs_client.models.avalanche_eval_problem_view_model import AvalancheEvalProblemViewModel
from varsom_regobs_client.models.avalanche_evaluation2_view_model import AvalancheEvaluation2ViewModel
from varsom_regobs_client.models.avalanche_evaluation3_dto import AvalancheEvaluation3Dto
from varsom_regobs_client.models.avalanche_evaluation3_view_model import AvalancheEvaluation3ViewModel
from varsom_regobs_client.models.avalanche_evaluation_view_model import AvalancheEvaluationViewModel
from varsom_regobs_client.models.avalanche_obs_dto import AvalancheObsDto
from varsom_regobs_client.models.avalanche_obs_view_model import AvalancheObsViewModel
from varsom_regobs_client.models.compression_test_dto import CompressionTestDto
from varsom_regobs_client.models.compression_test_view_model import CompressionTestViewModel
from varsom_regobs_client.models.county_dto import CountyDto
from varsom_regobs_client.models.create_account_request import CreateAccountRequest
from varsom_regobs_client.models.create_registration_request_dto import CreateRegistrationRequestDto
from varsom_regobs_client.models.create_registration_response_dto import CreateRegistrationResponseDto
from varsom_regobs_client.models.create_trip_dto import CreateTripDto
from varsom_regobs_client.models.damage_obs_dto import DamageObsDto
from varsom_regobs_client.models.damage_obs_view_model import DamageObsViewModel
from varsom_regobs_client.models.danger_obs_dto import DangerObsDto
from varsom_regobs_client.models.danger_obs_view_model import DangerObsViewModel
from varsom_regobs_client.models.density_profile_dto import DensityProfileDto
from varsom_regobs_client.models.density_profile_layer_dto import DensityProfileLayerDto
from varsom_regobs_client.models.finish_trip_dto import FinishTripDto
from varsom_regobs_client.models.forecast_region_dto import ForecastRegionDto
from varsom_regobs_client.models.forecast_region_sub_region_dto import ForecastRegionSubRegionDto
from varsom_regobs_client.models.general_observation_edit_model import GeneralObservationEditModel
from varsom_regobs_client.models.general_observation_view_model import GeneralObservationViewModel
from varsom_regobs_client.models.geo_location_info import GeoLocationInfo
from varsom_regobs_client.models.get_token_request_dto import GetTokenRequestDto
from varsom_regobs_client.models.get_token_response_dto import GetTokenResponseDto
from varsom_regobs_client.models.helptext_dto import HelptextDto
from varsom_regobs_client.models.ice_cover_obs_dto import IceCoverObsDto
from varsom_regobs_client.models.ice_cover_view_model import IceCoverViewModel
from varsom_regobs_client.models.ice_thickness_dto import IceThicknessDto
from varsom_regobs_client.models.ice_thickness_layer_dto import IceThicknessLayerDto
from varsom_regobs_client.models.ice_thickness_layer_view_model import IceThicknessLayerViewModel
from varsom_regobs_client.models.ice_thickness_view_model import IceThicknessViewModel
from varsom_regobs_client.models.incident_dto import IncidentDto
from varsom_regobs_client.models.incident_urls_dto import IncidentUrlsDto
from varsom_regobs_client.models.incident_view_model import IncidentViewModel
from varsom_regobs_client.models.kdv_element import KdvElement
from varsom_regobs_client.models.kdv_elements_response_dto import KdvElementsResponseDto
from varsom_regobs_client.models.land_slide_obs_dto import LandSlideObsDto
from varsom_regobs_client.models.landslide_view_model import LandslideViewModel
from varsom_regobs_client.models.lat_lng_object import LatLngObject
from varsom_regobs_client.models.my_page_data import MyPageData
from varsom_regobs_client.models.obs_location_dto import ObsLocationDto
from varsom_regobs_client.models.obs_location_view_model import ObsLocationViewModel
from varsom_regobs_client.models.obs_locations_response_dto_v2 import ObsLocationsResponseDtoV2
from varsom_regobs_client.models.observer_competence_dto import ObserverCompetenceDto
from varsom_regobs_client.models.observer_competence_level_dto import ObserverCompetenceLevelDto
from varsom_regobs_client.models.observer_group_dto import ObserverGroupDto
from varsom_regobs_client.models.observer_response_dto import ObserverResponseDto
from varsom_regobs_client.models.observer_view_model import ObserverViewModel
from varsom_regobs_client.models.picture_request_dto import PictureRequestDto
from varsom_regobs_client.models.position_dto import PositionDto
from varsom_regobs_client.models.reg_obs_generic_value import RegObsGenericValue
from varsom_regobs_client.models.registration_type_criteria_dto import RegistrationTypeCriteriaDto
from varsom_regobs_client.models.registration_type_dto import RegistrationTypeDto
from varsom_regobs_client.models.registration_type_sub_type_dto import RegistrationTypeSubTypeDto
from varsom_regobs_client.models.registration_view_model import RegistrationViewModel
from varsom_regobs_client.models.search_count_response_dto import SearchCountResponseDto
from varsom_regobs_client.models.search_criteria_request_dto import SearchCriteriaRequestDto
from varsom_regobs_client.models.search_side_bar_dto import SearchSideBarDto
from varsom_regobs_client.models.search_side_bar_request_dto import SearchSideBarRequestDto
from varsom_regobs_client.models.snow_cover_obs_dto import SnowCoverObsDto
from varsom_regobs_client.models.snow_cover_obs_view_model import SnowCoverObsViewModel
from varsom_regobs_client.models.snow_density_layer_view_model import SnowDensityLayerViewModel
from varsom_regobs_client.models.snow_density_view_model import SnowDensityViewModel
from varsom_regobs_client.models.snow_profile_dto import SnowProfileDto
from varsom_regobs_client.models.snow_profile_view_model import SnowProfileViewModel
from varsom_regobs_client.models.snow_surface_observation_dto import SnowSurfaceObservationDto
from varsom_regobs_client.models.snow_surface_view_model import SnowSurfaceViewModel
from varsom_regobs_client.models.snow_temp_obs_view_model import SnowTempObsViewModel
from varsom_regobs_client.models.snow_temp_view_model import SnowTempViewModel
from varsom_regobs_client.models.strat_profile_dto import StratProfileDto
from varsom_regobs_client.models.strat_profile_layer_dto import StratProfileLayerDto
from varsom_regobs_client.models.strat_profile_layer_view_model import StratProfileLayerViewModel
from varsom_regobs_client.models.strat_profile_view_model import StratProfileViewModel
from varsom_regobs_client.models.summary import Summary
from varsom_regobs_client.models.temp_obs_dto import TempObsDto
from varsom_regobs_client.models.temp_profile_obs_dto import TempProfileObsDto
from varsom_regobs_client.models.url_view_model import UrlViewModel
from varsom_regobs_client.models.water_level2_dto import WaterLevel2Dto
from varsom_regobs_client.models.water_level_dto import WaterLevelDto
from varsom_regobs_client.models.water_level_measurement_dto import WaterLevelMeasurementDto
from varsom_regobs_client.models.water_level_measurement_view_model import WaterLevelMeasurementViewModel
from varsom_regobs_client.models.water_level_view_model import WaterLevelViewModel
from varsom_regobs_client.models.waterlevel2_view_model import Waterlevel2ViewModel
from varsom_regobs_client.models.weather_observation_dto import WeatherObservationDto
from varsom_regobs_client.models.weather_view_model import WeatherViewModel
from varsom_regobs_client.models.within_extent_criteria_dto import WithinExtentCriteriaDto
from varsom_regobs_client.models.within_radius_criteria_dto import WithinRadiusCriteriaDto
